# Krakatoa
## _ A easy to use Machine Learning interface _


[![Build Status](https://travis-ci.org/joemccann/dillinger.svg?branch=master)](https://travis-ci.org/joemccann/dillinger)

Krakatoa is a high level coding, user friendly machine learning package.
With few lines of coding you will be rapidly able to:
- Load your data
- Preprocess your data
- Get insights
- Run machine learning algorithms
 
## Alpha Phase - in progress 

